@@ -84,7 +84,8 @@ KEY_OPENSHIFT_NAMESPACE = "OPENSHIFT_NAMESPACE"
 KEY_OPENSHIFT_APPLICATION = "OPENSHIFT_APPLICATION"
 KEY_PROCESSING_OPERATIONS_APPLICATION = "PROCESSING_OPERATIONS_APPLICATION"
 KEY_DATA_ENCRYPTION_HANDLER_APPLICATION = "DATA_ENCRYPTION_HANDLER_APPLICATION"
-
+KEY_DEPLOY_CONTEXT = "DEPLOY_CONTEXT"
+KEY_REST_DEPLOY_CONTEXT = "REST_DEPLOY_CONTEXT"
 
 class SettingsManager(object):
     def __init__(self, config_file_location):
