@@ -39,6 +39,7 @@ Surface relates DataTypes.
 import warnings
 import numpy
 import scipy.sparse
+from io import BytesIO
 
 from tvb.basic import exceptions
 from tvb.basic.neotraits.api import TVBEnum
@@ -155,18 +156,39 @@ class Surface(HasTraits):
     valid_for_simulations = Attr(field_type=bool, default=True)
 
     @classmethod
-    def from_file(cls, source_file="cortex_16384.zip"):
-        """Construct a Surface from source_file."""
-
+    def _read(cls, reader):
         result = cls()
-        source_full_path = try_get_absolute_path("tvb_data.surfaceData", source_file)
-        reader = ZipReader(source_full_path)
-
         result.vertices = reader.read_array_from_file("vertices.txt")
         result.vertex_normals = reader.read_array_from_file("normals.txt")
         result.triangles = reader.read_array_from_file("triangles.txt", dtype=numpy.int32)
         return result
 
+    @classmethod
+    def from_file(cls, source_file="cortex_16384.zip"):
+        """Construct a Surface from source_file."""
+        source_full_path = try_get_absolute_path("tvb_data.surfaceData", source_file)
+        reader = ZipReader(source_full_path)
+
+        return cls._read(reader)
+
+    @classmethod
+    def from_bytes_stream(cls, bytes_stream):
+        """Construct a Surface from a stream of bytes."""
+
+        reader = ZipReader(BytesIO(bytes_stream))
+        return cls._read(reader)
+
+    def set_scaled_vertices(self, new_vertices):
+        # The vertex values can be too small to be seen with the viewers or widgets, thus we scale them a bit
+        vertices_mean = numpy.mean(new_vertices)
+        if vertices_mean < 0.1:
+            new_vertices = new_vertices * 1000
+        elif vertices_mean < 1:
+            new_vertices = new_vertices * 100
+        elif vertices_mean < 10:
+            new_vertices = new_vertices * 10
+        self.vertices = new_vertices
+
     def configure(self):
         """Compute additional attributes on surface data required for full functionality."""
 
@@ -384,7 +406,7 @@ class Surface(HasTraits):
                 vert_norms[k, :] = self.vertices[k] / numpy.sqrt(self.vertices[k].dot(self.vertices[k]))
                 bad_normal_count += 1
         if bad_normal_count:
-            self.logger.warning(" %d vertices have bad normals" % bad_normal_count)
+            self.log.warning(" %d vertices have bad normals" % bad_normal_count)
         self.vertex_normals = vert_norms
         self.log.debug("vertex_normals")
         self.log.debug(narray_describe(self.vertex_normals))
@@ -521,7 +543,6 @@ class Surface(HasTraits):
             self._edge_lengths = elem
         return self._edge_lengths
 
-
     @property
     def edge_triangles(self):
         """
