@@ -97,6 +97,7 @@ class BaseHistory(StaticAttr):
             if sim.surface is not None:
                 n_node = sim.number_of_nodes
             history = sim.model.initial_for_simulator(sim.integrator, (n_time, n_svar, n_node, n_mode))
+            initial_conditions = history[n_time - 1]
         # ICs provided
         else:
             # history should be [timepoints, state_variables, nodes, modes]
@@ -135,9 +136,17 @@ class BaseHistory(StaticAttr):
             sim.integrator.bound_and_clamp(history[it])
         sim.log.info('Final initial history shape is %r', history.shape)
 
-        # create initial state from history
-        sim.current_state = history[sim.current_step % sim.connectivity.horizon].copy()
-        sim.log.debug('initial state has shape %r' % (sim.current_state.shape, ))
+        # create initial state
+        if sim.surface:
+            # ensure 4D
+            # TODO refactor to backend
+            initial_conditions = initial_conditions.reshape((-1, ) + initial_conditions.shape[-3:])
+            sim.current_state = initial_conditions[-1].copy()
+        else:
+            sim.current_state = history[sim.current_step % sim.connectivity.horizon].copy()
+        sim.log.info('initial state has shape %r' % (sim.current_state.shape, ))
+
+        # create history buffer
         if sim.surface is not None and history.shape[2] > sim.connectivity.number_of_regions:
             n_reg = sim.connectivity.number_of_regions
             (nt, ns, _, nm), ax = history.shape, (2, 0, 1, 3)
@@ -146,6 +155,7 @@ class BaseHistory(StaticAttr):
             region_history /= numpy.bincount(sim.surface.region_mapping).reshape((-1, 1))
             history = region_history
 
+        # init history instance
         inst = cls(sim.connectivity.weights, sim.connectivity.idelays,
                    sim.model.cvar, sim.model.number_of_modes)
         inst.initialize(history)
@@ -204,7 +214,7 @@ class SparseHistory(DenseHistory):
     n_nnzw = Dim()
     n_nnzr = Dim()
     time_stride = Dim()
-    nnz_mask = NDArray(('n_node', 'n_node'), numpy.bool)
+    nnz_mask = NDArray(('n_node', 'n_node'), numpy.bool_)
     const_indices = NDArray(('n_cvar', n_nnzw, 'n_mode'), 'i')
     nnz_idelays = NDArray((n_nnzw,), 'i')
     nnz_row_el_idx = NDArray((n_nnzw, ), 'i')
